/* 
 * Copyright 2012 Jared Bunting, Peach Jean Solutions <jared.bunting@peachjean.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */

package net.peachjean.restmx.console.application;

import com.google.common.collect.ImmutableSet;
import net.peachjean.restmx.console.providers.JsonItemProvider;
import net.peachjean.restmx.console.providers.ServerConnectionProviderResolver;
import net.peachjean.restmx.console.providers.TemplateItemProvider;
import net.peachjean.restmx.console.resource.*;
import net.peachjean.restmx.server.DefaultLocalServerConnectionProvider;
import net.peachjean.restmx.server.ServerConnectionProvider;

import javax.ws.rs.core.Application;
import java.util.Set;

public class RestMxApplication extends Application {

	final ServerConnectionProvider serverConnectionProvider;

	public RestMxApplication(final ServerConnectionProvider serverConnectionProvider) {
		this.serverConnectionProvider = serverConnectionProvider;
	}

	public RestMxApplication() {
		this(new DefaultLocalServerConnectionProvider());
	}

	@Override
	public Set<Class<?>> getClasses() {
		return ImmutableSet.<Class<?>>builder()
				.add(ServerResource.class)
				.add(DomainResource.class)
				.add(MBeanResource.class)
				.add(AttributeResource.class)
				.add(OperationResource.class)

				.add(IndexResource.class)
				.add(JSResource.class)

				.add(JsonItemProvider.class)
				.add(TemplateItemProvider.class)

				.build();
	}

	@Override
	public Set<Object> getSingletons() {
		return ImmutableSet.builder()
				.add(new ServerConnectionProviderResolver(this.serverConnectionProvider))
				.build();
	}
}
