/* 
 * Copyright 2012 Jared Bunting, Peach Jean Solutions <jared.bunting@peachjean.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */

package net.peachjean.restmx.console.resource;

import com.google.common.collect.ImmutableList;
import net.peachjean.restmx.console.model.MxListModel;
import net.peachjean.restmx.console.model.MxModel;
import net.peachjean.restmx.server.ServerConnectionProvider;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import java.io.IOException;

@Path("/servers/{server}/domains")
public class DomainResource {

	@Context
	private ServerConnectionProvider serverConnectionProvider;


	@Path("{domain}")
	@GET
	@Produces({MediaType.TEXT_HTML, MediaType.TEXT_PLAIN, MediaType.APPLICATION_JSON})
	public MxModel getDomain(@PathParam("domain") final String domain) {
		return new MxListModel(domain, "list", ImmutableList.of("mbeans"));
	}

	@GET
	@Produces({MediaType.TEXT_HTML, MediaType.TEXT_PLAIN, MediaType.APPLICATION_JSON})
	public MxModel getDomains(@PathParam("server") final String server) throws IOException {
		return new MxListModel("domains", "list", ImmutableList
				.copyOf(serverConnectionProvider.getConnection(server).getDomains()));
	}
}
