/* 
 * Copyright 2012 Jared Bunting, Peach Jean Solutions <jared.bunting@peachjean.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */

package net.peachjean.restmx.console.resource;

import net.peachjean.restmx.console.model.MxListModel;
import net.peachjean.restmx.console.model.MxModel;
import net.peachjean.restmx.server.ServerConnectionProvider;

import javax.management.*;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

@Path("/servers/{server}/domains/{domain}/mbeans")
public class MBeanResource {
	@Context
	private ServerConnectionProvider serverConnectionProvider;

	@Path("{mbean}")
	@GET
	@Produces({MediaType.TEXT_HTML, MediaType.TEXT_PLAIN, MediaType.APPLICATION_JSON})
	public MxModel getMBean(@PathParam("server") final String server,
	                        @PathParam("domain") final String domain,
	                        @PathParam("mbean") final String mbean) {
		List<Object> result = new ArrayList<Object>();

		MBeanServerConnection serverConnection = serverConnectionProvider.getConnection(server);

		try {
			if (serverConnection.getMBeanInfo(new ObjectName(domain + ":" + mbean)).getAttributes().length > 0) {
				result.add("attributes");
			}

			if (serverConnection.getMBeanInfo(new ObjectName(domain + ":" + mbean)).getOperations().length > 0) {
				result.add("operations");
			}
		} catch (InstanceNotFoundException e) {
			throw new RuntimeException(e);
		} catch (IntrospectionException e) {
			throw new RuntimeException(e);
		} catch (MalformedObjectNameException e) {
			throw new RuntimeException(e);
		} catch (ReflectionException e) {
			throw new RuntimeException(e);
		} catch (NullPointerException e) {
			throw new RuntimeException(e);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}

		return new MxListModel(mbean, "list", result);
	}

	@GET
	@Produces({MediaType.TEXT_HTML, MediaType.TEXT_PLAIN, MediaType.APPLICATION_JSON})
	public MxModel listMBeans(@PathParam("server") final String server,
	                          @PathParam("domain") final String domain) {
		try {
			MBeanServerConnection serverConnection = serverConnectionProvider.getConnection(server);

			List<ObjectName> names =
					new ArrayList<ObjectName>(serverConnection.queryNames(new ObjectName(domain + ":*"), null));

			List<String> result = new ArrayList<String>();

			for (Object name : names) {
				result.add(name.toString().substring(domain.length() + 1));
			}
			Collections.sort(result);

			return new MxListModel("mbeans", "list", result);
		} catch (IOException e) {
			throw new RuntimeException(e);
		} catch (MalformedObjectNameException e) {
			throw new RuntimeException(e);
		}

	}

}
