/*
 * Copyright 2012 Jared Bunting, Peach Jean Solutions <jared.bunting@peachjean.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package net.peachjean.restmx.console.resource;

import com.google.common.collect.ImmutableMap;
import com.google.common.io.Resources;

import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import java.io.IOException;
import java.net.URL;

public class StaticResourceSupport {
	private static final ImmutableMap<String, MediaType> mediaTypeExtensionMap = buildExtensionMap();

	private static ImmutableMap<String, MediaType> buildExtensionMap() {
		return ImmutableMap.<String, MediaType>builder()
				.put("html", MediaType.TEXT_HTML_TYPE)
				.put("gif", new MediaType("image", "gif"))
				.put("png", new MediaType("image", "png"))
				.put("js", new MediaType("text", "javascript"))
				.put("css", new MediaType("text", "css"))

				.build();
	}

	protected Response retrieveResource(final String resource) throws IOException {
		URL resourceUrl = Resources.getResource(resource);

		if (resourceUrl != null) {
			return Response.ok(Resources.toByteArray(resourceUrl), determineMediaType(resource)).build();
		} else {
			return Response.noContent().status(Response.Status.NOT_FOUND).build();
		}
	}

	private MediaType determineMediaType(final String resource) {
		int lastDot = resource.lastIndexOf(".");
		if (lastDot < 0) {
			throw new IllegalArgumentException("No extension found for resource " + resource);
		}
		String extension = resource.substring(lastDot + 1);
		if (mediaTypeExtensionMap.containsKey(extension)) {
			return mediaTypeExtensionMap.get(extension);
		} else {
			throw new IllegalArgumentException("Cannot resolve mediatype for extension " + extension);
		}
	}
}
