/*
 * Copyright 2012 Jared Bunting, Peach Jean Solutions <jared.bunting@peachjean.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package net.peachjean.restmx.console.tool;

import net.peachjean.restmx.console.servlet.RestMXServlet;
import org.eclipse.jetty.jmx.MBeanContainer;
import org.eclipse.jetty.server.Connector;
import org.eclipse.jetty.server.Server;
import org.eclipse.jetty.server.handler.ContextHandlerCollection;
import org.eclipse.jetty.server.nio.SelectChannelConnector;
import org.eclipse.jetty.servlet.ServletContextHandler;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.lang.management.ManagementFactory;

public class StandaloneRestMX {
	private static final Logger logger = LoggerFactory.getLogger(StandaloneRestMX.class);

	public static void main(final String[] args) throws Exception {
		Server server = new Server();
		if (setupJmx()) {
			MBeanContainer mbContainer = new MBeanContainer(ManagementFactory.getPlatformMBeanServer());
			mbContainer.start();
			server.getContainer().addEventListener(mbContainer);
			server.addBean(mbContainer, true);
		}

		Connector connector = new SelectChannelConnector();
		connector.setPort(Integer.getInteger("jetty.port", 8182).intValue());
		server.setConnectors(new Connector[]{connector});

		ContextHandlerCollection contexts = new ContextHandlerCollection();

		ServletContextHandler root = new ServletContextHandler(contexts, "/", ServletContextHandler.SESSIONS);

		root.addServlet(RestMXServlet.class.getCanonicalName(), "/*");
		server.setHandler(contexts);

		server.start();
		System.err.println(server.dump());
		server.join();

	}

	private static boolean setupJmx() {
		try {
			MBeanContainer.class.getName();
			return true;
		} catch (Exception e) {
			logger.info("Not loading jetty jmx beans, as jetty-jmx was not found on the classpath.");
			return false;
		}
	}
}
