/* 
 * ------------------------------------------------------------------------------------------------
 * Copyright 2011 by Swiss Post, Information Technology Services
 * ------------------------------------------------------------------------------------------------
 * $Id: AbstractListServerConnectionProvider.java 56 2011-08-23 08:24:35Z laurent.bovet $
 * ------------------------------------------------------------------------------------------------
 *
 */
package net.peachjean.restmx.server;

import javax.management.MBeanServerConnection;
import java.util.ArrayList;
import java.util.List;

/**
 * Superclass for connection providers not providing server names.
 *
 * @author bovetl
 * @version $Revision: 56 $
 * @see <script>links('$HeadURL: http://jminix.googlecode.com/svn/trunk/jminix/src/main/java/org/jminix/server/AbstractListServerConnectionProvider.java $');</script>
 */
public abstract class AbstractListServerConnectionProvider implements ServerConnectionProvider {

	/**
	 * Not explicitly documented.
	 *
	 * @see net.peachjean.restmx.server.ServerConnectionProvider#getConnectionKeys()
	 */
	public List<String> getConnectionKeys() {
		List<String> result = new ArrayList<String>();
		for (int i = 0; i < getConnections().size(); i++) {
			result.add(Integer.toString(i));
		}
		return result;
	}

	/**
	 * Not explicitly documented.
	 *
	 * @see net.peachjean.restmx.server.ServerConnectionProvider#getConnection(java.lang.String)
	 */
	public MBeanServerConnection getConnection(String name) {
		int i = 0;
		try {
			i = Integer.parseInt(name);
		} catch (NumberFormatException e) {
			return null;
		}
		return getConnections().get(i);
	}

}
